@@ -1,7 +1,7 @@
 <?php
-    /*
-     *  Change Pass
+    /* change_pass
      *
+     * $Id: options.php,v 1.1 2003/09/19 18:46:07 indiri69 Exp $
      */
 
     define('SM_PATH', '../../');
@@ -10,6 +10,7 @@
     require_once (SM_PATH . 'functions/imap.php');
     require_once (SM_PATH . 'functions/prefs.php');
     require_once (SM_PATH . 'functions/global.php');
+    require_once (SM_PATH . 'functions/i18n.php');
 
     sqgetGlobalVar('plugin_change_pass', $plugin_change_pass, SQ_POST);
 
@@ -18,10 +19,17 @@
         sqgetGlobalVar('cp_oldpass', $cp_oldpass, SQ_POST);
         sqgetGlobalVar('cp_newpass', $cp_newpass, SQ_POST);
         sqgetGlobalVar('cp_verify',  $cp_verify,  SQ_POST);
+        bindtextdomain('change_pass', SM_PATH . 'plugins/change_pass/locale');
+        textdomain('change_pass');
         $messages = change_pass_check();
+        bindtextdomain('squirrelmail', SM_PATH . 'locale');
+        textdomain('squirrelmail');
     }
 
     displayPageHeader($color, 'None');
+
+    bindtextdomain('change_pass', SM_PATH . 'plugins/change_pass/locale');
+    textdomain('change_pass');
 ?>
     <table width="100%" cellpadding="2" cellspacing="2" border="0">
         <tr><td bgcolor="<?php echo $color[0] ?>">
@@ -44,13 +52,16 @@
                     _("New Password")        => 'cp_newpass',
                     _("Verify New Password") => 'cp_verify');
     foreach($values as $key=>$value) {
-        echo "<tr>\n<th align=\"right\">$key:</th>\n";
-        echo "<td>\n<input type=\"password\" name=\"$value\" size=\"20\">\n</td>\n";
-        echo "</tr>\n";
-    }
 ?>
+                <tr>
+                    <th align="right"><?php echo $key; ?></th>
+                    <td>
+                        <input type="password" name="<?php echo $value; ?>" size="20">
+                    </td>
+                </tr>
+<?php } ?>
                 <tr><td align="center" colspan="2">
-                    <input type="submit" value="Submit" name="plugin_change_pass">
+                    <input type="submit" value=<?php echo _("Submit"); ?> name="plugin_change_pass">
                 </td></tr>
             </table>
             </form>
@@ -58,9 +69,12 @@
     </table>
 </body></html>
 <?php
+    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+    textdomain('squirrelmail');
+
 function change_pass_closeport($pop_socket, &$messages, $debug) {
     if ($debug) {
-        array_push($messages, "Closing Connection");
+        array_push($messages, _("Closing Connection"));
     }
     fputs($pop_socket, "quit\r\n");
     fclose($pop_socket);
@@ -104,9 +118,11 @@ function change_pass_check($debug = 0) {
         $messages[] = _("Your old password is not correct.");
     }
     if (count($messages)) {
-        return $messages;
+        $return = $messages;
+    } else {
+        $return = change_pass_go($password, $debug);
     }
-    return change_pass_go($password, $debug);
+    return $return;
 }
 
 function change_pass_go($password, $debug) {
@@ -116,12 +132,14 @@ function change_pass_go($password, $debug) {
     sqgetGlobalVar('base_uri', $base_uri, SQ_SESSION);
     $messages = array();
 
+
     if ($debug) {
-        $messages[] = "Connecting to Password Server";
+        $messages[] = _("Connecting to Password Server");
     }
     $pop_socket = fsockopen($imapServerAddress, 106, $errno, $errstr);
     if (!$pop_socket) {
-        $messages[] = "ERROR: $errstr ($errno)";
+        $messages[] = _("ERROR:") .
+                     "$errstr ($errno)";
         return $messages;
     }
 
@@ -152,7 +170,7 @@ function change_pass_go($password, $debug) {
         return $messages;
 
     //if ($debug) {
-        $messages[] = 'Password changed successfully.';
+        $messages[] = _("Password changed successfully.");
     //}
     // Write new cookies for the password
     $onetimepad = OneTimePadCreate(strlen($cp_newpass));
